##############################
StorageExtBETA class
##############################

.. |br| raw:: html

   <br />

The extended storage class provides the option to formulate:

* fixed or maximum operation rates of the state of charge of a storage component as well as 
* time dependent cost factors for the charging operation..

**StorageExtBETA class description:**

.. automodule:: storageExt
.. autoclass:: StorageExtBETA
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: StorageExtBETA
   :parts: 1

|

**StorageExtModel class description:**

.. autoclass:: StorageExtModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: StorageExtModel
   :parts: 1

